const ImageBitmapWorker = function () {

  self.onmessage = function ( message ) {

    fetch( message.data.url )
      .then( ( response ) => response.blob() )
      .then( ( blob ) => self.createImageBitmap( blob ) )
      .then( ( imageBitmap ) => self.postMessage( imageBitmap ) )
      .catch( function ( error ) {

        console.warn( 'Worker error: ', error );
        self.postMessage( error );

      } );

  };

};

// Build a worker from an anonymous function body
const workerBlob = new Blob([ '(', ImageBitmapWorker.toString(), ')()' ], { type: 'application/javascript' } );
const workerBlobURL = URL.createObjectURL( workerBlob );

const worker = new Worker( workerBlobURL );

worker.postMessage( {
  url: `${location.protocol}//${location.host}/public/puppy.jpg`
} );

worker.onmessage = function ( message ) {

  const result = message.data;

  if ( result instanceof ImageBitmap ) {

    console.log(result);
    const canvasEl = document.querySelector( '#canvas' );
    const ctx = canvasEl.getContext( '2d' );
    ctx.drawImage( result, 0, 0 );

  } else {

    console.log( result );

  }

};

URL.revokeObjectURL( workerBlobURL );
